Learn R Programming

rcure (version 0.1.0)

printrcure: Prints rcure object

Description

Prints rcure object

Usage

printrcure(x, Var = TRUE, ROC = TRUE, ...)

Arguments

x
an object of rcure
Var
if it is TRUE, the funciton returns standard error estimated by bootstrap method. If it is False, the function only returns estimators of coefficients. By default, Var = TRUE
ROC
if TRUE, the function plots ROC. By default, ROC = TRUE
...
further arguments to be passed to the printrcure function

References

Cai, C., Zou, Y., Peng, Y., & Zhang, J. (2012). smcure: An R-Package for estimating semiparametric mixture cure models. Computer methods and programs in biomedicine, 108(3), 1255-1260